@@ -66,12 +66,18 @@ extern int capget(cap_user_header_t header, const cap_user_data_t data);
 
 // If we don't have the xattr library, then we can't
 // compile-in file system capabilities
-#ifndef HAVE_ATTR_XATTR_H
+#if !defined(HAVE_ATTR_XATTR_H) && !defined (HAVE_SYS_XATTR_H)
 #undef VFS_CAP_U32
 #endif
 
 #ifdef VFS_CAP_U32
- #include <attr/xattr.h>
+ #ifdef HAVE_SYS_XATTR_H
+   #include <sys/xattr.h>
+ #else
+  #ifdef HAVE_ATTR_XATTR_H
+   #include <attr/xattr.h>
+  #endif
+ #endif
  #if __BYTE_ORDER == __BIG_ENDIAN
   #define FIXUP(x) bswap_32(x)
  #else
@@ -239,7 +245,7 @@ static int get_bounding_set(void)
 #else
 		(unsigned)getpid();
 #endif
-	f = fopen(buf, "r");
+	f = fopen(buf, "re");
 	if (f == NULL)
 		return -1;
 	__fsetlocking(f, FSETLOCKING_BYCALLER);
@@ -898,6 +904,8 @@ char *capng_print_caps_text(capng_print_t where, capng_type_t which)
 	for (i=0; i<=CAP_LAST_CAP; i++) {
 		if (capng_have_capability(which, i)) {
 			const char *n = capng_capability_to_name(i);
+			if (n == NULL)
+				n = "unknown";
 			if (where == CAPNG_PRINT_STDOUT) {
 				if (once == 0) {
 					printf("%s", n);
