@@ -1,5 +1,5 @@
 /* captab.h --
- * Copyright 2009,2011 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009,2011-12 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -66,4 +66,16 @@ _S(CAP_SYSLOG,			"syslog"		)
 #ifdef CAP_WAKE_ALARM
 _S(CAP_WAKE_ALARM,		"wake_alarm"		)
 #endif
+#if defined(CAP_EPOLLWAKEUP) && defined(CAP_BLOCK_SUSPEND)
+#error "Both CAP_EPOLLWAKEUP and CAP_BLOCK_SUSPEND are defined"
+#endif
+#ifdef CAP_EPOLLWAKEUP
+_S(CAP_EPOLLWAKEUP,		"epollwakeup"		)
+#endif
+#ifdef CAP_BLOCK_SUSPEND
+_S(CAP_BLOCK_SUSPEND,		"block_suspend"		)
+#endif
+#ifdef CAP_COMPROMISE_KERNEL
+_S(CAP_COMPROMISE_KERNEL,	"compromise_kernel"	)
+#endif
 
